@@ -1,6 +1,6 @@
 //! # twilight-gateway
 //!
-//! [![discord badge][]][discord link] [![github badge][]][github link] [![license badge][]][license link] ![rust badge]
+//! [![codecov badge][]][codecov link] [![discord badge][]][discord link] [![github badge][]][github link] [![license badge][]][license link] ![rust badge]
 //!
 //! `twilight-gateway` is an implementation of Discord's sharding gateway sessions.
 //! This is responsible for receiving stateful events in real-time from Discord
@@ -17,6 +17,11 @@
 //! manages and proxies all of their events under one unified stream. This is
 //! useful to use if you have a large bot in over 1000 or 2000 guilds.
 //!
+//! ## Examples
+//!
+//! There are a few usage examples located in the [root of the `twilight`
+//! repository][github examples link].
+//!
 //! ## Features
 //!
 //! ### Deserialization
@@ -107,14 +112,17 @@
 //! [`tracing`]: https://crates.io/crates/tracing
 //! [`twilight-http`]: https://twilight-rs.github.io/twilight/twilight_http/index.html
 //! [`zlib-ng`]: https://github.com/zlib-ng/zlib-ng
+//! [codecov badge]: https://img.shields.io/codecov/c/gh/twilight-rs/twilight?logo=codecov&style=for-the-badge&token=E9ERLJL0L2
+//! [codecov link]: https://app.codecov.io/gh/twilight-rs/twilight/
 //! [discord badge]: https://img.shields.io/discord/745809834183753828?color=%237289DA&label=discord%20server&logo=discord&style=for-the-badge
 //! [discord link]: https://discord.gg/7jj8n7D
 //! [docs:discord:sharding]: https://discord.com/developers/docs/topics/gateway#sharding
 //! [github badge]: https://img.shields.io/badge/github-twilight-6f42c1.svg?style=for-the-badge&logo=github
+//! [github examples link]: https://github.com/twilight-rs/twilight/tree/main/examples
 //! [github link]: https://github.com/twilight-rs/twilight
 //! [license badge]: https://img.shields.io/badge/license-ISC-blue.svg?style=for-the-badge&logo=pastebin
 //! [license link]: https://github.com/twilight-rs/twilight/blob/main/LICENSE.md
-//! [rust badge]: https://img.shields.io/badge/rust-1.49+-93450a.svg?style=for-the-badge&logo=rust
+//! [rust badge]: https://img.shields.io/badge/rust-1.53+-93450a.svg?style=for-the-badge&logo=rust
 
 #![deny(
     clippy::all,
@@ -124,7 +132,7 @@
     missing_docs,
     nonstandard_style,
     rust_2018_idioms,
-    broken_intra_doc_links,
+    rustdoc::broken_intra_doc_links,
     unsafe_code,
     unused,
     warnings
