@@ -1,9 +1,9 @@
-use crate::EventTypeFlags;
+use crate::{shard::tls::TlsContainer, EventTypeFlags};
 use std::sync::Arc;
 use twilight_gateway_queue::Queue;
 use twilight_http::Client;
 use twilight_model::gateway::{
-    payload::{identify::IdentifyProperties, update_presence::UpdatePresencePayload},
+    payload::outgoing::{identify::IdentifyProperties, update_presence::UpdatePresencePayload},
     Intents,
 };
 
@@ -17,7 +17,7 @@ use twilight_model::gateway::{
 pub struct Config {
     pub(crate) event_types: EventTypeFlags,
     pub(crate) gateway_url: Option<Box<str>>,
-    pub(crate) http_client: Client,
+    pub(crate) http_client: Arc<Client>,
     pub(super) identify_properties: Option<IdentifyProperties>,
     pub(super) intents: Intents,
     pub(super) large_threshold: u64,
@@ -27,6 +27,7 @@ pub struct Config {
     pub(super) token: Box<str>,
     pub(crate) session_id: Option<Box<str>>,
     pub(crate) sequence: Option<u64>,
+    pub(crate) tls: Option<TlsContainer>,
 }
 
 impl Config {
@@ -42,7 +43,7 @@ impl Config {
 
     /// Return an immutable reference to the `twilight_http` client to be used
     /// by the shard.
-    pub const fn http_client(&self) -> &Client {
+    pub fn http_client(&self) -> &Client {
         &self.http_client
     }
 
